@@ -6,21 +6,24 @@ use Carp;
 use Time::HiRes;
 use Config;
 
-our $VERSION = '0.05';
-our $DEBUG = $ENV{FQ_DEBUG} || 0;
-our $DEFAULT_IMPL;
+our $VERSION = '0.06';
+our $DEBUG = $ENV{FORKS_QUEUE_DEBUG} || 0;
 
-our $NOTIFY_OK = $ENV{FQ_NOTIFY} // do {
+our $NOTIFY_OK = $ENV{FORKS_QUEUE_NOTIFY} // do {
     $Config::Config{sig_name} =~ /\bIO\b/;
-    0; # disable
+    1;
 };
 our $SLEEP_INTERVAL = $NOTIFY_OK ? 2 : 1;
-our $SLEEP_INTERVALX = 1;
+our $SLEEP_INTERVALX = 2;
+
+# default values to apply to all new Forks::Queue implementations
+our %OPTS = (limit => -1, on_limit => 'fail', style => 'fifo',
+             impl => $ENV{FORKS_QUEUE_IMPL} || 'File' );
 
 sub new {
-    my ($pkg,%opts) = @_;
-    $opts{impl} //= $DEFAULT_IMPL; # undocumented, included for convenience
-                                   # of adapting tests in tqt/*.t
+    my $pkg = shift;
+    my %opts = (%OPTS, @_);
+
     if ($opts{impl}) {
         $pkg = delete $opts{impl};
         if ($pkg =~ /[^\w:]/) {
@@ -40,6 +43,18 @@ sub new {
         "Use an implementation or pass the 'impl' option to the constructor";
 }
 
+sub import {
+    my ($class, @args) = @_;
+    for (my $i=0; $i<@args; $i++) {
+        foreach my $key (qw(limit on_limit impl style)) {
+            if ($args[$i] eq $key) {
+                $OPTS{$args[$i]} = $args[$i+1];
+                $i++;
+                next;
+            }
+        }
+    }
+}
 
 sub put {
     my $self = CORE::shift;
@@ -178,7 +193,7 @@ Forks::Queue - queue that can be shared across processes
 
 =head1 VERSION
 
-0.05
+0.06
 
 =head1 SYNOPSIS
 
@@ -232,15 +247,8 @@ Instantiates a new queue object with the given configuration.
 If one of the options is C<impl>, the constructor from that
 C<Forks::Queue> subclass will be invoked.
 
-If the C<impl> option is not provided, this call will fail.
+Other options that should be supported on all implementations include
 
-Options that should be supported on all implementations include
-
-=cut
-
-# not documented yet: set $Forks::Queue::DEFAULT_IMPL to set
-# implementation to be used whenever  impl => ...  is not specified
-    
 =over 4
 
 =item * C<< style => 'fifo' | 'lifo' >>
@@ -331,6 +339,9 @@ could be added to an already existing queue.
 
 =back
 
+See the global L<"%OPTS"/"%OPTS"> variable for information about
+default values for many of these settings.
+
 =head2 put
 
 =head2 enqueue
@@ -644,6 +655,63 @@ or C<fail>, which returns immediately from an insertion operation with
 a warning about items that were not added to the queue.
 
 
+=head1 VARIABLES
+
+=head2 %OPTS
+
+Global hash containing the set of default options for all
+C<Forks::Queue> constructors. Initially this hash contains the
+key-value pairs
+
+        impl            "File"
+        style           "fifo"
+        limit           -1
+        on_limit        "fail"
+
+but they may be changed at any time to affect all subsequently
+constructed C<Forks::Queue> objects. The global options can also
+be set at import time with additional arguments for the C<use>
+statement.
+
+    use Forks::Queue impl => 'SQLite';    # use SQLite queues by default
+    $Forks::Queue::OPTS{impl} = 'SQLite'; # equivalent run-time call
+    
+    use Forks::Queue
+        on_limit => 'block', limit => 10; # finite, blocking queues by default
+    $Forks::Queue::OPTS{limit} = 10;
+    $Forks::Queue::OPTS{on_limit} = 'block';  # equivalent run-time calls
+
+=head1 ENVIRONMENT
+
+Some environment variable settings that can affect this module:
+
+=over 4
+
+=item * FORKS_QUEUE_IMPL
+
+Specifies a default implementation to use, overriding the initial setting
+of C<$Forks::Queue::OPTS{"impl"}>, in cases where the C<Forks::Queue>
+constructor is invoked without passing an C<impl> option.
+
+=item * FORKS_QUEUE_DEBUG
+
+If set to a true value, outputs information about the activity of
+the queues to standard error.
+
+=item * FORKS_QUEUE_NOTIFY
+
+If set to a false value, disables use of signals on POSIX-y platforms
+that may help improve queue performance
+
+=item * FORKS_QUEUE_DIR
+
+Specifies a directory to use for temporary queue files in the
+L<File|Forks::Queue::File> and L<SQLite|Forks::Queue::SQLite> implementations.
+If this directory is not specified, the implementations will try to make
+a reasonable choice based on your platform and other environment settings.
+
+=back
+
 =head1 DEPENDENCIES
 
 The C<Forks::Queue> module and all its current implementations require
