@@ -8,7 +8,7 @@ use Time::HiRes;
 use base 'Forks::Queue';
 use 5.010;    #  using  // //=  operators
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 our $DEBUG;
 *DEBUG = \$Forks::Queue::DEBUG;
 
@@ -81,12 +81,11 @@ sub _PID {
 }
 
 sub new {
-    my ($class, %opts) = @_;
+    my $class = shift;
+    my %opts = (%Forks::Queue::OPTS, @_);
+
     $opts{file} //= _impute_file();
     $opts{lock} = $opts{file} . ".lock";
-    $opts{limit} //= -1;
-    $opts{on_limit} //= 'fail';
-    $opts{style} //= 'fifo';
     my $list = delete $opts{list};
 
     my $fh;
@@ -159,8 +158,10 @@ sub DESTROY {
     } $self;
     };
     if ($@) {
-        use Data::Dumper;
-        print STDERR Dumper($@,$self);
+        if ($@ !~ /malformed JSON ...* at character offset 0/) {
+            use Data::Dumper;
+            print STDERR Dumper($@,$self);
+        }
     }
     close $self->{_fh};
     $DEBUG and print STDERR "$$ DESTROY: remaining pids: ",
@@ -1058,7 +1059,7 @@ Forks::Queue::File - file-based implementation of Forks::Queue
 
 =head1 VERSION
 
-0.05
+0.06
 
 =head1 SYNOPSIS
 
