@@ -9,8 +9,8 @@ use Time::HiRes 'time';
 use base 'Forks::Queue';
 use 5.010;    #  using  // //=  operators
 
-our $VERSION = '0.05';
-our $DEBUG;
+our $VERSION = '0.06';
+our ($DEBUG,$XDEBUG);
 *DEBUG = \$Forks::Queue::DEBUG;
 
 $SIG{IO} = sub { } if $Forks::Queue::NOTIFY_OK;
@@ -18,7 +18,9 @@ $SIG{IO} = sub { } if $Forks::Queue::NOTIFY_OK;
 our $jsonizer = JSON->new->allow_nonref(1)->ascii(1);
 
 sub new {
-    my ($class, %opts) = @_;
+    my $class = shift;
+    my %opts = (%Forks::Queue::OPTS, @_);
+
     if ($opts{join} && !$opts{db_file}) {
         croak "Forks::Queue::SQLite: db_file opt required with join";
     }
@@ -212,11 +214,13 @@ sub Forks::Queue::SQLite::MagicLimit::TIESCALAR {
 }
 
 sub Forks::Queue::SQLite::MagicLimit::FETCH {
+    $XDEBUG && print STDERR "MagicLimit::FETCH => ",${$_[0]}->{limit},"\n";
     return ${$_[0]}->{limit};
 }
 
 sub Forks::Queue::SQLite::MagicLimit::STORE {
     my ($tie,$val) = @_;
+    $XDEBUG && print STDERR "MagicLimit::STORE => $val\n";
     my $queue = $$tie;
     my $oldval  = $queue->{limit};
     $queue->{limit} = $val;
@@ -232,17 +236,21 @@ sub limit :lvalue {
     my $self = CORE::shift;
     if (!$self->{_limit_magic}) {
         tie $self->{_limit_magic}, 'Forks::Queue::SQLite::MagicLimit', $self;
+        $XDEBUG && print STDERR "tied \$self->\{_limit_magic\}\n";
     }
 
     if (@_) {
+        $XDEBUG && print STDERR "setting _limit_magic to $_[0]\n";
         $self->{_limit_magic} = CORE::shift(@_);
         if (@_) {
+            $XDEBUG && print STDERR "setting on_limit to $_[0]\n";
             $self->_dbh->begin_work;
             $self->_status("on_limit", $self->{on_limit} = $_[0]);
             $self->_dbh->commit;
         }
     } else {
         $self->{limit} = $self->_status("limit");
+        $XDEBUG && print STDERR "updating {limit} to $self->{limit}\n";
     }
     return $self->{_limit_magic};
 }
@@ -812,7 +820,7 @@ Forks::Queue::SQLite - SQLite-based implementation of Forks::Queue
 
 =head1 VERSION
 
-0.05
+0.06
 
 =head1 SYNOPSIS
 
