@@ -4,13 +4,14 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 our $DEV_SHM = "/dev/shm";
 our $DEBUG;
 *DEBUG = \$Forks::Queue::DEBUG;
 
 sub new {
-    my ($class, %opts) = @_;
+    my $class = shift;
+    my %opts = (%Forks::Queue::OPTS, @_);
 
     if (! -d $DEV_SHM) {
         croak "\$DEV_SHM not set to a valid shared memory virtual filesystem";
@@ -115,7 +116,7 @@ Forks::Queue::Shmem - Forks::Queue implementation using shared memory
 
 =head1 VERSION
 
-0.05
+0.06
 
 =head1 DESCRIPTION
 
